@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Get XML.
 has xml => (
@@ -220,6 +220,67 @@ For more information about Singapore Map, click L<here|https://en.wikipedia.org/
  # North East MRT Line
  # North South MRT Line
 
+=head1 EXAMPLE5
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Singapore;
+
+ # Arguments.
+ if (@ARGV < 1) {
+         print STDERR "Usage: $0 line\n";
+         exit 1;
+ }
+ my $line = $ARGV[0];
+
+ # Object.
+ my $obj = Map::Tube::Singapore->new;
+
+ # Get stations for line.
+ my $stations_ar = $obj->get_stations($line);
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } @{$stations_ar};
+
+ # Output:
+ # Usage: __PROG__ line
+
+ # Output with 'foo' argument.
+ # Map::Tube::get_stations(): ERROR: Invalid Line Name [foo]. (status: 105) file __PROG__ on line __LINE__
+
+ # Output with 'Circle MRT Line' argument.
+ # Dhoby Ghaut
+ # Bras Basah
+ # Esplanade
+ # Promenade
+ # Nicoll Highway
+ # Stadium
+ # Mountbatten
+ # Dakota
+ # Paya Lebar
+ # MacPherson
+ # Tai Seng
+ # Bartley
+ # Serangoon
+ # Lorong Chuan
+ # Bishan
+ # Marymount
+ # Caldecott
+ # Botanic Gardens
+ # Farrer Road
+ # Buona Vista
+ # one-north
+ # Kent Ridge
+ # Haw Par Villa
+ # Pasir Panjang
+ # Labrador Park
+ # Telok Blangah
+ # HarbourFront
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -263,6 +324,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
